==> mongodb-src-r4.4.3.tar.gz: mongodb-src-r4.4.3/src/mongo/logv2/log_capture_backend.h <==
/**
 *    Copyright (C) 2020-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <boost/log/attributes/attribute_value_set.hpp>
#include <boost/log/core/record_view.hpp>
#include <boost/log/sinks.hpp>
#include <boost/log/utility/formatting_ostream.hpp>
#include <boost/make_shared.hpp>
#include <string>
#include <vector>

namespace mongo::logv2 {
class LogCaptureBackend
    : public boost::log::sinks::
          basic_formatted_sink_backend<char, boost::log::sinks::synchronized_feeding> {
public:
    LogCaptureBackend(std::vector<std::string>& lines) : _logLines(lines) {}

    static boost::shared_ptr<boost::log::sinks::synchronous_sink<LogCaptureBackend>> create(
        std::vector<std::string>& lines) {
        return boost::make_shared<boost::log::sinks::synchronous_sink<LogCaptureBackend>>(
            boost::make_shared<LogCaptureBackend>(lines));
    }

    void consume(boost::log::record_view const& rec, string_type const& formatted_string) {
        _logLines.push_back(formatted_string);
    }

private:
    std::vector<std::string>& _logLines;
};
}  // namespace mongo::logv2

==> mongodb-src-r5.2.1.tar.gz: mongodb-src-r5.2.1/src/mongo/logv2/log_capture_backend.h <==
/**
 *    Copyright (C) 2020-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <boost/log/attributes/attribute_value_set.hpp>
#include <boost/log/core/record_view.hpp>
#include <boost/log/sinks.hpp>
#include <boost/log/utility/formatting_ostream.hpp>
#include <boost/make_shared.hpp>
#include <string>
#include <vector>

namespace mongo::logv2 {
class LogCaptureBackend
    : public boost::log::sinks::
          basic_formatted_sink_backend<char, boost::log::sinks::synchronized_feeding> {
public:
    LogCaptureBackend(std::vector<std::string>& lines, bool stripEol)
        : _stripEol(stripEol), _logLines(lines) {}

    static boost::shared_ptr<boost::log::sinks::synchronous_sink<LogCaptureBackend>> create(
        std::vector<std::string>& lines, bool stripEol) {
        return boost::make_shared<boost::log::sinks::synchronous_sink<LogCaptureBackend>>(
            boost::make_shared<LogCaptureBackend>(lines, stripEol));
    }

    void consume(boost::log::record_view const& rec, string_type const& formatted_string) {
        if (_stripEol && !formatted_string.empty() &&
            formatted_string[formatted_string.size() - 1] == '\n') {
            _logLines.push_back(formatted_string.substr(0, formatted_string.size() - 1));
        } else {
            _logLines.push_back(formatted_string);
        }
    }

private:
    bool _stripEol;
    std::vector<std::string>& _logLines;
};
}  // namespace mongo::logv2
